@@ -1,5 +1,5 @@
 /* Look at first character in UTF-8 string.
-   Copyright (C) 1999-2002, 2006-2007, 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 1999-2002, 2006-2007, 2009-2023 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2001.
 
    This file is free software: you can redistribute it and/or modify
@@ -62,20 +62,15 @@ u8_mbtouc (ucs4_t *puc, const uint8_t *s, size_t n)
         {
           if (n >= 3)
             {
-              if ((s[1] ^ 0x80) < 0x40)
+              if ((s[1] ^ 0x80) < 0x40
+                  && (c >= 0xe1 || s[1] >= 0xa0)
+                  && (c != 0xed || s[1] < 0xa0))
                 {
                   if ((s[2] ^ 0x80) < 0x40)
                     {
-                      if ((c >= 0xe1 || s[1] >= 0xa0)
-                          && (c != 0xed || s[1] < 0xa0))
-                        {
-                          *puc = ((unsigned int) (c & 0x0f) << 12)
-                                 | ((unsigned int) (s[1] ^ 0x80) << 6)
-                                 | (unsigned int) (s[2] ^ 0x80);
-                          return 3;
-                        }
-                      /* invalid multibyte character */
-                      *puc = 0xfffd;
+                      *puc = ((unsigned int) (c & 0x0f) << 12)
+                             | ((unsigned int) (s[1] ^ 0x80) << 6)
+                             | (unsigned int) (s[2] ^ 0x80);
                       return 3;
                     }
                   /* invalid multibyte character */
@@ -83,38 +78,50 @@ u8_mbtouc (ucs4_t *puc, const uint8_t *s, size_t n)
                   return 2;
                 }
               /* invalid multibyte character */
+              *puc = 0xfffd;
+              return 1;
             }
           else
             {
-              /* incomplete multibyte character */
               *puc = 0xfffd;
-              if (n == 1 || (s[1] ^ 0x80) >= 0x40)
-                return 1;
+              if (n == 1)
+                {
+                  /* incomplete multibyte character */
+                  return 1;
+                }
               else
-                return 2;
+                {
+                  if ((s[1] ^ 0x80) < 0x40
+                      && (c >= 0xe1 || s[1] >= 0xa0)
+                      && (c != 0xed || s[1] < 0xa0))
+                    {
+                      /* incomplete multibyte character */
+                      return 2;
+                    }
+                  else
+                    {
+                      /* invalid multibyte character */
+                      return 1;
+                    }
+                }
             }
         }
-      else if (c < 0xf8)
+      else if (c <= 0xf4)
         {
           if (n >= 4)
             {
-              if ((s[1] ^ 0x80) < 0x40)
+              if ((s[1] ^ 0x80) < 0x40
+                  && (c >= 0xf1 || s[1] >= 0x90)
+                  && (c < 0xf4 || (/* c == 0xf4 && */ s[1] < 0x90)))
                 {
                   if ((s[2] ^ 0x80) < 0x40)
                     {
                       if ((s[3] ^ 0x80) < 0x40)
                         {
-                          if ((c >= 0xf1 || s[1] >= 0x90)
-                              && (c < 0xf4 || (c == 0xf4 && s[1] < 0x90)))
-                            {
-                              *puc = ((unsigned int) (c & 0x07) << 18)
-                                     | ((unsigned int) (s[1] ^ 0x80) << 12)
-                                     | ((unsigned int) (s[2] ^ 0x80) << 6)
-                                     | (unsigned int) (s[3] ^ 0x80);
-                              return 4;
-                            }
-                          /* invalid multibyte character */
-                          *puc = 0xfffd;
+                          *puc = ((unsigned int) (c & 0x07) << 18)
+                                 | ((unsigned int) (s[1] ^ 0x80) << 12)
+                                 | ((unsigned int) (s[2] ^ 0x80) << 6)
+                                 | (unsigned int) (s[3] ^ 0x80);
                           return 4;
                         }
                       /* invalid multibyte character */
@@ -126,17 +133,48 @@ u8_mbtouc (ucs4_t *puc, const uint8_t *s, size_t n)
                   return 2;
                 }
               /* invalid multibyte character */
+              *puc = 0xfffd;
+              return 1;
             }
           else
             {
-              /* incomplete multibyte character */
               *puc = 0xfffd;
-              if (n == 1 || (s[1] ^ 0x80) >= 0x40)
-                return 1;
-              else if (n == 2 || (s[2] ^ 0x80) >= 0x40)
-                return 2;
+              if (n == 1)
+                {
+                  /* incomplete multibyte character */
+                  return 1;
+                }
               else
-                return 3;
+                {
+                  if ((s[1] ^ 0x80) < 0x40
+                      && (c >= 0xf1 || s[1] >= 0x90)
+                      && (c < 0xf4 || (/* c == 0xf4 && */ s[1] < 0x90)))
+                    {
+                      if (n == 2)
+                        {
+                          /* incomplete multibyte character */
+                          return 2;
+                        }
+                      else
+                        {
+                          if ((s[2] ^ 0x80) < 0x40)
+                            {
+                              /* incomplete multibyte character */
+                              return 3;
+                            }
+                          else
+                            {
+                              /* invalid multibyte character */
+                              return 2;
+                            }
+                        }
+                    }
+                  else
+                    {
+                      /* invalid multibyte character */
+                      return 1;
+                    }
+                }
             }
         }
     }
