@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1993-2023 The Octave Project Developers
+// Copyright (C) 1993-2024 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -60,7 +60,6 @@
 #include "ov-class.h"
 #include "ov-usr-fcn.h"
 #include "pager.h"
-#include "parse.h"
 #include "pt-eval.h"
 #include "syminfo.h"
 #include "symtab.h"
@@ -558,7 +557,7 @@ wants_local_change (const octave_value_list& args, int& nargin)
 }
 
 static octave::unwind_protect *
-curr_fcn_unwind_protect_frame (void)
+curr_fcn_unwind_protect_frame ()
 {
   octave::tree_evaluator& tw = octave::__get_evaluator__ ();
 
@@ -949,7 +948,7 @@ name_matches_any_pattern (const std::string& nm, const string_vector& argv,
             }
           else
             {
-              glob_match pattern (patstr);
+              symbol_match pattern (patstr);
 
               if (pattern.match (nm))
                 {
@@ -1162,7 +1161,8 @@ Match zero or more characters.
 Match the list of characters specified by @var{list}.  If the first character
 is @code{!} or @code{^}, match all characters except those specified by
 @var{list}.  For example, the pattern @code{[a-zA-Z]} will match all lowercase
-and uppercase alphabetic characters.
+and uppercase alphabetic characters.  On Windows, square brackets are matched
+literally and are not used to group characters.
 @end table
 
 For example, the command
@@ -1430,7 +1430,7 @@ maybe_missing_function_hook (const std::string& name)
       Vmissing_function_hook.clear ();
 
       // Call.
-      octave_value_list tmp = octave::feval (fcn_name, octave_value (name), 1);
+      octave_value_list tmp = interp.feval (fcn_name, octave_value (name), 1);
 
       if (tmp.length () == 1 && tmp(0).is_string ())
         return tmp(0).string_value ();
