@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2007-2021 The Octave Project Developers
+// Copyright (C) 2007-2024 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -51,15 +51,17 @@ To initialize:
 #include "interpreter.h"
 #include "ov.h"
 #include "ovl.h"
-#include "parse.h"
 #include "utils.h"
 #include "variables.h"
 
 // PKG_ADD: if (__have_gnuplot__ ()) register_graphics_toolkit ("gnuplot"); endif
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 class gnuplot_graphics_toolkit : public octave::base_graphics_toolkit
 {
 public:
+
   gnuplot_graphics_toolkit (octave::interpreter& interp)
     : octave::base_graphics_toolkit ("gnuplot"), m_interpreter (interp)
   {
@@ -68,25 +70,27 @@ public:
     if (! warned)
       {
         warning_with_id
-          ("Octave:gnuplot-graphics",
-           "using the gnuplot graphics toolkit is discouraged\n\
+        ("Octave:gnuplot-graphics",
+         "using the gnuplot graphics toolkit is discouraged\n\
 \n\
 The gnuplot graphics toolkit is not actively maintained and has a number\n\
-of limitations that are ulikely to be fixed.  Communication with gnuplot\n\
+of limitations that are unlikely to be fixed.  Communication with gnuplot\n\
 uses a one-directional pipe and limited information is passed back to the\n\
 Octave interpreter so most changes made interactively in the plot window\n\
 will not be reflected in the graphics properties managed by Octave.  For\n\
 example, if the plot window is closed with a mouse click, Octave will not\n\
-be notified and will not update it's internal list of open figure windows.\n\
-We recommend using the qt toolkit instead.\n");
+be notified and will not update its internal list of open figure windows.\n\
+The qt toolkit is recommended instead.\n");
 
-          warned = true;
+        warned = true;
       }
   }
 
-  ~gnuplot_graphics_toolkit (void) = default;
+  OCTAVE_DISABLE_CONSTRUCT_COPY_MOVE (gnuplot_graphics_toolkit)
 
-  bool is_valid (void) const { return true; }
+  ~gnuplot_graphics_toolkit () = default;
+
+  bool is_valid () const { return true; }
 
   bool initialize (const graphics_object& go)
   {
@@ -134,13 +138,11 @@ We recommend using the qt toolkit instead.\n");
     // Prevent recursion
     if (! drawnow_executing)
       {
-        octave::unwind_protect frame;
-        frame.protect_var (drawnow_executing);
+        octave::unwind_protect_var<bool> restore_var (drawnow_executing, true);
 
-        drawnow_executing = true;
         octave_value_list args;
         args(0) = go.get_handle ().as_octave_value ();
-        octave::feval ("__gnuplot_drawnow__", args);
+        m_interpreter.feval ("__gnuplot_drawnow__", args);
       }
   }
 
@@ -154,7 +156,7 @@ We recommend using the qt toolkit instead.\n");
     args(2) = file;
     args(1) = term;
     args(0) = go.get_handle ().as_octave_value ();
-    octave::feval ("__gnuplot_drawnow__", args);
+    m_interpreter.feval ("__gnuplot_drawnow__", args);
   }
 
   Matrix get_canvas_size (const graphics_handle&) const
@@ -163,13 +165,13 @@ We recommend using the qt toolkit instead.\n");
     return sz;
   }
 
-  double get_screen_resolution (void) const
+  double get_screen_resolution () const
   { return 72.0; }
 
-  Matrix get_screen_size (void) const
+  Matrix get_screen_size () const
   { return Matrix (1, 2, 0.0); }
 
-  void close (void)
+  void close ()
   {
     if (m_interpreter.mislocked ("__init_gnuplot__"))
       m_interpreter.munlock ("__init_gnuplot__");
@@ -184,17 +186,17 @@ private:
         octave_value_list args;
         Matrix fids = pstream.matrix_value ();
 
-        Ffputs (m_interpreter, ovl (fids(0), "\nquit;\n"));
+        octave::Ffputs (m_interpreter, ovl (fids(0), "\nquit;\n"));
 
-        Ffflush (m_interpreter, ovl (fids(0)));
-        Fpclose (m_interpreter, ovl (fids(0)));
+        octave::Ffflush (m_interpreter, ovl (fids(0)));
+        octave::Fpclose (m_interpreter, ovl (fids(0)));
 
         if (fids.numel () > 1)
           {
-            Fpclose (m_interpreter, ovl (fids(1)));
+            octave::Fpclose (m_interpreter, ovl (fids(1)));
 
             if (fids.numel () > 2)
-              Fwaitpid (ovl (fids(2)));
+              octave::Fwaitpid (ovl (fids(2)));
           }
       }
   }
@@ -203,7 +205,7 @@ private:
 };
 
 static bool
-have_gnuplot_binary (void)
+have_gnuplot_binary (interpreter& interp)
 {
   const std::string exeext = octave::build_env::EXEEXT;
   const std::string path = octave::sys::env::getenv ("PATH");
@@ -212,7 +214,7 @@ have_gnuplot_binary (void)
   try
     {
       octave_value_list tmp
-        = octave::feval ("gnuplot_binary", octave_value_list ());
+        = interp.feval ("gnuplot_binary", octave_value_list ());
 
       if (tmp(0).is_string () && ! tmp(0).isempty ())
         {
@@ -235,11 +237,8 @@ have_gnuplot_binary (void)
           retval = fs.exists ();
         }
     }
-  catch (octave::execution_exception&)
+  catch (const octave::execution_exception&)
     {
-      octave::interpreter& interp
-        = octave::__get_interpreter__ ("have_gnuplot_binary");
-
       interp.recover_from_exception ();
     }
 
@@ -254,13 +253,13 @@ DEFMETHOD_DLD (__init_gnuplot__, interp, , ,
 Undocumented internal function.
 @end deftypefn */)
 {
-  if (! have_gnuplot_binary ())
+  if (! have_gnuplot_binary (interp))
     error ("__init_gnuplot__: the gnuplot program is not available, see 'gnuplot_binary'");
   else if (! interp.mislocked ("__init_gnuplot__"))
     {
-      octave::gtk_manager& gtk_mgr = interp.get_gtk_manager ();
+      gtk_manager& gtk_mgr = interp.get_gtk_manager ();
 
-      octave::graphics_toolkit tk (new gnuplot_graphics_toolkit (interp));
+      graphics_toolkit tk (new gnuplot_graphics_toolkit (interp));
       gtk_mgr.load_toolkit (tk);
 
       interp.mlock ();
@@ -269,16 +268,18 @@ Undocumented internal function.
   return octave_value_list ();
 }
 
-DEFUN_DLD (__have_gnuplot__, , ,
-           doc: /* -*- texinfo -*-
+DEFMETHOD_DLD (__have_gnuplot__, interp, , ,
+               doc: /* -*- texinfo -*-
 @deftypefn {} {@var{gnuplot_available} =} __have_gnuplot__ ()
 Undocumented internal function.
 @end deftypefn */)
 {
-  return ovl (have_gnuplot_binary ());
+  return ovl (have_gnuplot_binary (interp));
 }
 
 /*
 ## No test needed for internal helper function.
 %!assert (1)
 */
+
+OCTAVE_END_NAMESPACE(octave)
