@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2024 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -44,6 +44,8 @@
 #include "xdiv.h"
 #include "xpow.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 // matrix by complex matrix ops.
 
 DEFNDBINOP_OP (add, float_matrix, float_complex_matrix, float_array,
@@ -55,10 +57,8 @@ DEFBINOP_OP (mul, float_matrix, float_complex_matrix, *)
 
 DEFBINOP (trans_mul, float_matrix, float_complex_matrix)
 {
-  const octave_float_matrix& v1
-    = dynamic_cast<const octave_float_matrix&> (a1);
-  const octave_float_complex_matrix& v2
-    = dynamic_cast<const octave_float_complex_matrix&> (a2);
+  OCTAVE_CAST_BASE_VALUE (const octave_float_matrix&, v1, a1);
+  OCTAVE_CAST_BASE_VALUE (const octave_float_complex_matrix&, v2, a2);
 
   FloatMatrix m1 = v1.float_matrix_value ();
   FloatComplexMatrix m2 = v2.float_complex_matrix_value ();
@@ -69,10 +69,8 @@ DEFBINOP (trans_mul, float_matrix, float_complex_matrix)
 
 DEFBINOP (div, float_matrix, float_complex_matrix)
 {
-  const octave_float_matrix& v1
-    = dynamic_cast<const octave_float_matrix&> (a1);
-  const octave_float_complex_matrix& v2
-    = dynamic_cast<const octave_float_complex_matrix&> (a2);
+  OCTAVE_CAST_BASE_VALUE (const octave_float_matrix&, v1, a1);
+  OCTAVE_CAST_BASE_VALUE (const octave_float_complex_matrix&, v2, a2);
   MatrixType typ = v2.matrix_type ();
 
   FloatComplexMatrix ret = xdiv (v1.float_matrix_value (),
@@ -89,10 +87,8 @@ DEFBINOPX (pow, float_matrix, float_complex_matrix)
 
 DEFBINOP (ldiv, float_matrix, float_complex_matrix)
 {
-  const octave_float_matrix& v1
-    = dynamic_cast<const octave_float_matrix&> (a1);
-  const octave_float_complex_matrix& v2
-    = dynamic_cast<const octave_float_complex_matrix&> (a2);
+  OCTAVE_CAST_BASE_VALUE (const octave_float_matrix&, v1, a1);
+  OCTAVE_CAST_BASE_VALUE (const octave_float_complex_matrix&, v2, a2);
   MatrixType typ = v1.matrix_type ();
 
   FloatComplexMatrix ret = xleftdiv (v1.float_matrix_value (),
@@ -104,10 +100,8 @@ DEFBINOP (ldiv, float_matrix, float_complex_matrix)
 
 DEFBINOP (trans_ldiv, float_matrix, float_complex_matrix)
 {
-  const octave_float_matrix& v1
-    = dynamic_cast<const octave_float_matrix&> (a1);
-  const octave_float_complex_matrix& v2
-    = dynamic_cast<const octave_float_complex_matrix&> (a2);
+  OCTAVE_CAST_BASE_VALUE (const octave_float_matrix&, v1, a1);
+  OCTAVE_CAST_BASE_VALUE (const octave_float_complex_matrix&, v2, a2);
   MatrixType typ = v1.matrix_type ();
 
   FloatComplexMatrix ret = xleftdiv (v1.float_matrix_value (),
@@ -140,10 +134,8 @@ DEFNDBINOP_FN (el_pow, float_matrix, float_complex_matrix, float_array,
 
 DEFBINOP (el_ldiv, float_matrix, float_complex_matrix)
 {
-  const octave_float_matrix& v1
-    = dynamic_cast<const octave_float_matrix&> (a1);
-  const octave_float_complex_matrix& v2
-    = dynamic_cast<const octave_float_complex_matrix&> (a2);
+  OCTAVE_CAST_BASE_VALUE (const octave_float_matrix&, v1, a1);
+  OCTAVE_CAST_BASE_VALUE (const octave_float_complex_matrix&, v2, a2);
 
   return quotient (v2.float_complex_array_value (), v1.float_array_value ());
 }
@@ -164,10 +156,10 @@ DEFNDCATOP_FN (fm_cm, float_matrix, complex_matrix, float_array,
 
 DEFCONV (float_complex_matrix_conv, float_matrix, float_complex_matrix)
 {
-  const octave_float_matrix& v = dynamic_cast<const octave_float_matrix&> (a);
+  OCTAVE_CAST_BASE_VALUE (const octave_float_matrix&, v, a);
 
   return new octave_float_complex_matrix (FloatComplexNDArray
-                                           (v.float_array_value ()));
+                                          (v.float_array_value ()));
 }
 
 void
@@ -230,3 +222,5 @@ install_fm_fcm_ops (octave::type_info& ti)
   INSTALL_WIDENOP_TI (ti, octave_float_matrix, octave_float_complex_matrix,
                       float_complex_matrix_conv);
 }
+
+OCTAVE_END_NAMESPACE(octave)
