@@ -1783,16 +1783,22 @@ Array<T, Alloc>::sort (int dim, sortmode mode) const
   if (dim < 0)
     (*current_liboctave_error_handler) ("sort: invalid dimension");
 
+  if (numel () < 1)  // input array is empty,
+    return *this;
+
+  if (dim >= ndims ())
+    {
+      // The dimension to sort along exceeds the array's dimensions,
+      // ==> array is already trivially sorted in such higher dimensions,
+      // ==> return early.
+
+      return *this;
+    }
+
   Array<T, Alloc> m (dims ());
 
   dim_vector dv = m.dims ();
 
-  if (m.numel () < 1)
-    return m;
-
-  if (dim >= dv.ndims ())
-    dv.resize (dim+1, 1);
-
   octave_idx_type ns = dv(dim);
   octave_idx_type iter = dv.numel () / ns;
   octave_idx_type stride = 1;
