@@ -1,5 +1,9 @@
-## Copyright (C) 2005-2018 William Poetra Yoga Hadisoeseno
-## Copyright (C) 2014-2018 Carnë Draug
+########################################################################
+##
+## Copyright (C) 2005-2024 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -16,16 +20,19 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} license
 ## @deftypefnx {} {} license inuse
 ## @deftypefnx {} {} license inuse @var{feature}
 ## @deftypefnx {} {} license ("inuse")
-## @deftypefnx {} {@var{retval} =} license ("inuse")
-## @deftypefnx {} {@var{retval} =} license ("test", @var{feature})
-## @deftypefnx {} {@var{retval} =} license ("checkout", @var{feature})
-## @deftypefnx {} {[@var{retval}, @var{errmsg}] =} license ("checkout", @var{feature})
+## @deftypefnx {} {@var{license_struct} =} license ("inuse")
+## @deftypefnx {} {@var{license_struct} =} license ("inuse", @var{feature})
+## @deftypefnx {} {@var{status} =} license ("test", @var{feature})
+## @deftypefnx {} {@var{status} =} license ("checkout", @var{feature})
+## @deftypefnx {} {[@var{status}, @var{errmsg}] =} license ("checkout", @var{feature})
 ## Get license information for Octave and Octave packages.
 ##
 ## GNU Octave is free software distributed under the GNU General Public
@@ -35,12 +42,12 @@
 ## When called with no extra input arguments, it returns the Octave license,
 ## otherwise the first input defines the operation mode and must be one of
 ## the following strings: @code{inuse}, @code{test}, and @code{checkout}.
-## The optional @var{feature} argument can either be @qcode{"octave"} (core),
-## or an Octave package.
+## The optional @var{feature} argument can either be @qcode{"octave"} (core)
+## or the name of an Octave package.
 ##
 ## @table @asis
 ## @item @qcode{"inuse"}
-## Returns a list of loaded features, i.e., octave and the list of loaded
+## Print a list of loaded features, i.e., "octave" and the list of loaded
 ## packages.  If an output is requested, it returns a struct array with
 ## the fields @qcode{"feature"}, and @qcode{"user"}.
 ##
@@ -60,28 +67,18 @@
 ## @seealso{pkg, ver, version}
 ## @end deftypefn
 
-## Author: William Poetra Yoga Hadisoeseno <williampoetra@gmail.com>
+function [status, errmsg] = license (cmd, feature, toggle)
 
-function [retval, errmsg] = license (cmd, feature, toggle)
-
-  if (nargin > 3)
-    print_usage ();
-  endif
-
-  ## Then only give information about Octave core
   if (nargin == 0)
-    retval = "GNU General Public License";
+    ## then only give information about Octave core
+    status = "GNU General Public License";
     return;
   endif
 
   [features, loaded] = get_all_features ();
 
-  switch (tolower (cmd))
+  switch (lower (cmd))
     case "inuse"
-      if (nargin > 2)
-        print_usage ();
-      endif
-
       features = features(loaded);
 
       if (nargin > 1)
@@ -90,7 +87,7 @@ function [retval, errmsg] = license (cmd, feature, toggle)
       if (nargout == 0)
         printf ("%s\n", features{:});
       else
-        retval = struct ("feature", features, "user", get_username ());
+        status = struct ("feature", features, "user", get_username ());
       endif
 
     case "test"
@@ -102,14 +99,14 @@ function [retval, errmsg] = license (cmd, feature, toggle)
         ## We ignore the toggle argument because... what's the point?  We
         ## don't need a license management system on Octave.  This function
         ## will return true, even if anyone tries to disable a license.
-        switch (tolower (toggle))
+        switch (lower (toggle))
           case "enable"   # do nothing
           case "disable"  # do nothing
           otherwise       error ("license: TOGGLE must be enable or disable");
         endswitch
       endif
 
-      retval = any (strcmp (features, feature));
+      status = any (strcmp (features, feature));
 
     case "checkout"
       ## I guess we could have the checkout command load packages but it's not
@@ -120,10 +117,10 @@ function [retval, errmsg] = license (cmd, feature, toggle)
         print_usage ();
       endif
 
-      retval = any (strcmp (features, feature));
+      status = any (strcmp (features, feature));
       errmsg = "";
 
-      if (! retval)
+      if (! status)
         errmsg = ['No package named "' feature '" installed'];
       endif
 
@@ -134,12 +131,14 @@ function [retval, errmsg] = license (cmd, feature, toggle)
 endfunction
 
 function username = get_username ()
+
   pw = getpwuid (getuid ());
   if (isstruct (pw))
     username = pw.name;
   else
     username = "octave_user";
   endif
+
 endfunction
 
 function [features, loaded] = get_all_features ()
@@ -158,7 +157,7 @@ endfunction
 %! list = pkg ("list");
 %! for idx = 1: numel (list)
 %!   name = list{idx}.name;
-%!   if (list{idx}.loaded);
+%!   if (list{idx}.loaded)
 %!     assert ((license ("inuse", name)).feature, name);
 %!   else
 %!     rv = license ("inuse", name);
