@@ -1,10 +1,11 @@
 function x = subsref (g, s)
 
-  switch s.type
+  switch (s.type)
   case '.'
-    switch s.subs
+    switch (s.subs)
     case 'gyrk'
       x = g.gyrk;
+    end
   end
 
 end
